package javassist.bytecode;

import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.ListIterator;
import java.util.Map;

/* loaded from: javassist_bytecode.jar:javassist/bytecode/AttributeInfo.class */
public class AttributeInfo {
    protected ConstPool constPool;
    int name;
    byte[] info;

    /* JADX INFO: Access modifiers changed from: protected */
    public AttributeInfo(ConstPool cp, int attrname, byte[] attrinfo) {
        this.constPool = cp;
        this.name = attrname;
        this.info = attrinfo;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public AttributeInfo(ConstPool cp, String attrname) {
        this(cp, attrname, (byte[]) null);
    }

    public AttributeInfo(ConstPool cp, String attrname, byte[] attrinfo) {
        this(cp, cp.addUtf8Info(attrname), attrinfo);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public AttributeInfo(ConstPool cp, int n, DataInputStream in) throws IOException {
        this.constPool = cp;
        this.name = n;
        int len = in.readInt();
        this.info = new byte[len];
        if (len > 0) {
            in.readFully(this.info);
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static AttributeInfo read(ConstPool cp, DataInputStream in) throws IOException {
        int name = in.readUnsignedShort();
        String nameStr = cp.getUtf8Info(name);
        char first = nameStr.charAt(0);
        if (first < 'M') {
            if (first < 'E') {
                if (nameStr.equals(AnnotationDefaultAttribute.tag)) {
                    return new AnnotationDefaultAttribute(cp, name, in);
                }
                if (nameStr.equals(BootstrapMethodsAttribute.tag)) {
                    return new BootstrapMethodsAttribute(cp, name, in);
                }
                if (nameStr.equals(CodeAttribute.tag)) {
                    return new CodeAttribute(cp, name, in);
                }
                if (nameStr.equals(ConstantAttribute.tag)) {
                    return new ConstantAttribute(cp, name, in);
                }
                if (nameStr.equals(DeprecatedAttribute.tag)) {
                    return new DeprecatedAttribute(cp, name, in);
                }
            } else {
                if (nameStr.equals(EnclosingMethodAttribute.tag)) {
                    return new EnclosingMethodAttribute(cp, name, in);
                }
                if (nameStr.equals(ExceptionsAttribute.tag)) {
                    return new ExceptionsAttribute(cp, name, in);
                }
                if (nameStr.equals(InnerClassesAttribute.tag)) {
                    return new InnerClassesAttribute(cp, name, in);
                }
                if (nameStr.equals(LineNumberAttribute.tag)) {
                    return new LineNumberAttribute(cp, name, in);
                }
                if (nameStr.equals(LocalVariableAttribute.tag)) {
                    return new LocalVariableAttribute(cp, name, in);
                }
                if (nameStr.equals("LocalVariableTypeTable")) {
                    return new LocalVariableTypeAttribute(cp, name, in);
                }
            }
        } else if (first < 'S') {
            if (nameStr.equals(MethodParametersAttribute.tag)) {
                return new MethodParametersAttribute(cp, name, in);
            }
            if (nameStr.equals(AnnotationsAttribute.visibleTag) || nameStr.equals(AnnotationsAttribute.invisibleTag)) {
                return new AnnotationsAttribute(cp, name, in);
            }
            if (nameStr.equals(ParameterAnnotationsAttribute.visibleTag) || nameStr.equals(ParameterAnnotationsAttribute.invisibleTag)) {
                return new ParameterAnnotationsAttribute(cp, name, in);
            }
            if (nameStr.equals(TypeAnnotationsAttribute.visibleTag) || nameStr.equals(TypeAnnotationsAttribute.invisibleTag)) {
                return new TypeAnnotationsAttribute(cp, name, in);
            }
        } else {
            if (nameStr.equals(SignatureAttribute.tag)) {
                return new SignatureAttribute(cp, name, in);
            }
            if (nameStr.equals(SourceFileAttribute.tag)) {
                return new SourceFileAttribute(cp, name, in);
            }
            if (nameStr.equals(SyntheticAttribute.tag)) {
                return new SyntheticAttribute(cp, name, in);
            }
            if (nameStr.equals(StackMap.tag)) {
                return new StackMap(cp, name, in);
            }
            if (nameStr.equals(StackMapTable.tag)) {
                return new StackMapTable(cp, name, in);
            }
        }
        return new AttributeInfo(cp, name, in);
    }

    public String getName() {
        return this.constPool.getUtf8Info(this.name);
    }

    public ConstPool getConstPool() {
        return this.constPool;
    }

    public int length() {
        return this.info.length + 6;
    }

    public byte[] get() {
        return this.info;
    }

    public void set(byte[] newinfo) {
        this.info = newinfo;
    }

    public AttributeInfo copy(ConstPool newCp, Map classnames) {
        int s = this.info.length;
        byte[] srcInfo = this.info;
        byte[] newInfo = new byte[s];
        for (int i = 0; i < s; i++) {
            newInfo[i] = srcInfo[i];
        }
        return new AttributeInfo(newCp, getName(), newInfo);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void write(DataOutputStream out) throws IOException {
        out.writeShort(this.name);
        out.writeInt(this.info.length);
        if (this.info.length > 0) {
            out.write(this.info);
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static int getLength(ArrayList list) {
        int size = 0;
        int n = list.size();
        for (int i = 0; i < n; i++) {
            AttributeInfo attr = (AttributeInfo) list.get(i);
            size += attr.length();
        }
        return size;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static AttributeInfo lookup(ArrayList list, String name) {
        if (list == null) {
            return null;
        }
        ListIterator iterator = list.listIterator();
        while (iterator.hasNext()) {
            AttributeInfo ai = (AttributeInfo) iterator.next();
            if (ai.getName().equals(name)) {
                return ai;
            }
        }
        return null;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static synchronized void remove(ArrayList list, String name) {
        if (list == null) {
            return;
        }
        ListIterator iterator = list.listIterator();
        while (iterator.hasNext()) {
            AttributeInfo ai = (AttributeInfo) iterator.next();
            if (ai.getName().equals(name)) {
                iterator.remove();
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static void writeAll(ArrayList list, DataOutputStream out) throws IOException {
        if (list == null) {
            return;
        }
        int n = list.size();
        for (int i = 0; i < n; i++) {
            AttributeInfo attr = (AttributeInfo) list.get(i);
            attr.write(out);
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static ArrayList copyAll(ArrayList list, ConstPool cp) {
        if (list == null) {
            return null;
        }
        ArrayList newList = new ArrayList();
        int n = list.size();
        for (int i = 0; i < n; i++) {
            AttributeInfo attr = (AttributeInfo) list.get(i);
            newList.add(attr.copy(cp, null));
        }
        return newList;
    }

    void renameClass(String oldname, String newname) {
    }

    void renameClass(Map classnames) {
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static void renameClass(List attributes, String oldname, String newname) {
        Iterator iterator = attributes.iterator();
        while (iterator.hasNext()) {
            AttributeInfo ai = (AttributeInfo) iterator.next();
            ai.renameClass(oldname, newname);
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static void renameClass(List attributes, Map classnames) {
        Iterator iterator = attributes.iterator();
        while (iterator.hasNext()) {
            AttributeInfo ai = (AttributeInfo) iterator.next();
            ai.renameClass(classnames);
        }
    }

    void getRefClasses(Map classnames) {
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static void getRefClasses(List attributes, Map classnames) {
        Iterator iterator = attributes.iterator();
        while (iterator.hasNext()) {
            AttributeInfo ai = (AttributeInfo) iterator.next();
            ai.getRefClasses(classnames);
        }
    }
}
